Documentation
¶
Overview ¶
Package ui provides an embedded web-based kanban board for gig. Usage:
server := ui.New(store)
server.ListenAndServe(":9741")
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateData ¶
CreateData is the template data for the create form.
type DepInfo ¶
type DepInfo struct {
Task *gig.Task
Dep *gig.Dependency
}
DepInfo pairs a dependency with its task info.
type DetailData ¶
type DetailData struct {
Task *gig.Task
Comments []*gig.Comment
DepsOn []*DepInfo
Blocks []*DepInfo
Children []*gig.Task
ChildrenColumns []Column
Events []*gig.Event
AllTasks []*gig.Task
}
DetailData is the template data for the task detail view.
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server is the gig web UI server.
func (*Server) ListenAndServe ¶
ListenAndServe starts the HTTP server on the given address (e.g. ":9741").
Click to show internal directories.
Click to hide internal directories.